==> wire-grpc-client-3.2.0-javadoc.jar: wire-grpc-client/com.squareup.wire/-grpc-client/index.md <==
[wire-grpc-client](../../index.md) / [com.squareup.wire](../index.md) / [GrpcClient](./index.md)

# GrpcClient

`expect class GrpcClient`

**Platform and version requirements:** JVM, js, native

### Types

| Name | Summary |
|---|---|
| [Builder](-builder/index.md)<br>(JVM) | `class Builder` |

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md)<br>(js, native) | `GrpcClient()` |

### Functions

| Name | Summary |
|---|---|
| [newCall](new-call.md) | `fun <S : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, R : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> newCall(method: `[`GrpcMethod`](../-grpc-method/index.md)`<`[`S`](new-call.md#S)`, `[`R`](new-call.md#R)`>): `[`GrpcCall`](../-grpc-call/index.md)`<`[`S`](new-call.md#S)`, `[`R`](new-call.md#R)`>`<br>`actual fun <S : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, R : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> newCall(method: <ERROR CLASS><`[`S`](new-call.md#S)`, `[`R`](new-call.md#R)`>): <ERROR CLASS><`[`S`](new-call.md#S)`, `[`R`](new-call.md#R)`>` |
| [newStreamingCall](new-streaming-call.md) | `fun <S : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, R : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> newStreamingCall(method: `[`GrpcMethod`](../-grpc-method/index.md)`<`[`S`](new-streaming-call.md#S)`, `[`R`](new-streaming-call.md#R)`>): `[`GrpcStreamingCall`](../-grpc-streaming-call/index.md)`<`[`S`](new-streaming-call.md#S)`, `[`R`](new-streaming-call.md#R)`>`<br>`actual fun <S : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, R : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> newStreamingCall(method: <ERROR CLASS><`[`S`](new-streaming-call.md#S)`, `[`R`](new-streaming-call.md#R)`>): <ERROR CLASS><`[`S`](new-streaming-call.md#S)`, `[`R`](new-streaming-call.md#R)`>` |

==> wire-grpc-client-3.2.2-javadoc.jar: wire-grpc-client/com.squareup.wire/-grpc-client/index.md <==
[wire-grpc-client](../../index.md) / [com.squareup.wire](../index.md) / [GrpcClient](./index.md)

# GrpcClient

`expect class GrpcClient`

**Platform and version requirements:** JVM, js, native

### Types

| Name | Summary |
|---|---|
| [Builder](-builder/index.md)<br>(JVM) | `class Builder` |

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md)<br>(js, native) | `GrpcClient()` |

### Functions

| Name | Summary |
|---|---|
| [create](create.md)<br>(JVM) | `fun <T> create(): `[`T`](create.md#T)<br>Returns a [T](create.md#T) that makes gRPC calls using this client.`fun <T> create(service: `[`KClass`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)`<`[`T`](create.md#T)`>): `[`T`](create.md#T)<br>Returns a [service](create.md#com.squareup.wire.GrpcClient$create(kotlin.reflect.KClass((com.squareup.wire.GrpcClient.create.T)))/service) that makes gRPC calls using this client. |
| [newCall](new-call.md) | `fun <S : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, R : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> newCall(method: `[`GrpcMethod`](../-grpc-method/index.md)`<`[`S`](new-call.md#S)`, `[`R`](new-call.md#R)`>): `[`GrpcCall`](../-grpc-call/index.md)`<`[`S`](new-call.md#S)`, `[`R`](new-call.md#R)`>`<br>`actual fun <S : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, R : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> newCall(method: <ERROR CLASS><`[`S`](new-call.md#S)`, `[`R`](new-call.md#R)`>): <ERROR CLASS><`[`S`](new-call.md#S)`, `[`R`](new-call.md#R)`>` |
| [newStreamingCall](new-streaming-call.md) | `fun <S : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, R : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> newStreamingCall(method: `[`GrpcMethod`](../-grpc-method/index.md)`<`[`S`](new-streaming-call.md#S)`, `[`R`](new-streaming-call.md#R)`>): `[`GrpcStreamingCall`](../-grpc-streaming-call/index.md)`<`[`S`](new-streaming-call.md#S)`, `[`R`](new-streaming-call.md#R)`>`<br>`actual fun <S : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, R : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> newStreamingCall(method: <ERROR CLASS><`[`S`](new-streaming-call.md#S)`, `[`R`](new-streaming-call.md#R)`>): <ERROR CLASS><`[`S`](new-streaming-call.md#S)`, `[`R`](new-streaming-call.md#R)`>` |
